<?php
/**
 * Archive options
 *
 * @package Theme Palace
 * @subpackage Architectonic Pro
 * @since Architectonic Pro 1.0.0
 */

// Add archive section
$wp_customize->add_section( 'architectonic_pro_archive_section', array(
	'title'             => esc_html__( 'Blog/Archive','architectonic-pro' ),
	'description'       => esc_html__( 'Archive section options.', 'architectonic-pro' ),
	'panel'             => 'architectonic_pro_theme_options_panel',
) );

// Your latest posts title setting and control.
$wp_customize->add_setting( 'architectonic_pro_theme_options[your_latest_posts_title]', array(
	'default'           => $options['your_latest_posts_title'],
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'architectonic_pro_theme_options[your_latest_posts_title]', array(
	'label'             => esc_html__( 'Your Latest Posts Title', 'architectonic-pro' ),
	'description'       => esc_html__( 'This option only works if Static Front Page is set to "Your latest posts."', 'architectonic-pro' ),
	'section'           => 'architectonic_pro_archive_section',
	'type'				=> 'text',
	'active_callback'   => 'architectonic_pro_is_latest_posts'
) );

// Archive date meta setting and control.
$wp_customize->add_setting( 'architectonic_pro_theme_options[hide_date]', array(
	'default'           => $options['hide_date'],
	'sanitize_callback' => 'architectonic_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Architectonic_Pro_Switch_Control( $wp_customize, 'architectonic_pro_theme_options[hide_date]', array(
	'label'             => esc_html__( 'Hide Date', 'architectonic-pro' ),
	'section'           => 'architectonic_pro_archive_section',
	'on_off_label' 		=> architectonic_pro_hide_options(),
) ) );

// Archive author category setting and control.
$wp_customize->add_setting( 'architectonic_pro_theme_options[hide_category]', array(
	'default'           => $options['hide_category'],
	'sanitize_callback' => 'architectonic_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Architectonic_Pro_Switch_Control( $wp_customize, 'architectonic_pro_theme_options[hide_category]', array(
	'label'             => esc_html__( 'Hide Category', 'architectonic-pro' ),
	'section'           => 'architectonic_pro_archive_section',
	'on_off_label' 		=> architectonic_pro_hide_options(),
) ) );

// Blog content type control and setting
$wp_customize->add_setting( 'architectonic_pro_theme_options[archive_column]', array(
	'default'          	=> $options['archive_column'],
	'sanitize_callback' => 'architectonic_pro_sanitize_select',
) );

$wp_customize->add_control( 'architectonic_pro_theme_options[archive_column]', array(
	'label'             => esc_html__( 'Column Layout', 'architectonic-pro' ),
	'section'           => 'architectonic_pro_archive_section',
	'type'				=> 'select',
	'choices'			=> array( 
		'col-2' 	=> esc_html__( 'Two Column', 'architectonic-pro' ),
		'col-3' 	=> esc_html__( 'Three Column', 'architectonic-pro' ),
	),
) );